@@ -1,6 +1,7 @@
 #coding:utf-8
 import datetime
 import functools
+import os
 import uuid
 from decimal import Decimal as Dc
 from types import MethodType
@@ -15,6 +16,7 @@ from .base import ModelTestCase
 from .base import TestModel
 from .base import db_loader
 from .base import requires_models
+from .base import skip_if
 from .base import skip_unless
 from .base_models import Register
 from .base_models import Tweet
@@ -58,22 +60,18 @@ class FTSModel(TestModel):
     fts_data = TSVectorField()
 
 
-try:
-    class JsonModel(TestModel):
-        data = JSONField()
+class JsonModel(TestModel):
+    data = JSONField()
 
-    class JsonModelNull(TestModel):
-        data = JSONField(null=True)
+class JsonModelNull(TestModel):
+    data = JSONField(null=True)
 
-    class BJson(TestModel):
-        data = BinaryJSONField()
+class BJson(TestModel):
+    data = BinaryJSONField()
 
-    class JData(TestModel):
-        d1 = BinaryJSONField()
-        d2 = BinaryJSONField(index=False)
-except:
-    BJson = JData = None
-    JsonModel = JsonModelNull = None
+class JData(TestModel):
+    d1 = BinaryJSONField()
+    d2 = BinaryJSONField(index=False)
 
 
 class Normal(TestModel):
@@ -93,6 +91,7 @@ class TestTZField(ModelTestCase):
     database = db
     requires = [TZModel]
 
+    @skip_if(os.environ.get('CI'), 'running in ci mode, skipping')
     def test_tz_field(self):
         self.database.set_time_zone('us/eastern')
 
@@ -101,7 +100,7 @@ class TestTZField(ModelTestCase):
         tz = TZModel.create(dt=dt)
         self.assertTrue(tz.dt.tzinfo is None)
 
-        # When we retrieve the row, psycopg2 will attach the appropriate tzinfo
+        # When we retrieve the row, psycopg will attach the appropriate tzinfo
         # data. The value is returned as an "aware" datetime in US/Eastern.
         tz_db = TZModel[tz.id]
         self.assertTrue(tz_db.dt.tzinfo is not None)
@@ -470,11 +469,6 @@ class TestArrayUUIDField(ModelTestCase):
     database = db
     requires = [UUIDList]
 
-    def setUp(self):
-        super(TestArrayUUIDField, self).setUp()
-        import psycopg2.extras
-        psycopg2.extras.register_uuid()
-
     def test_array_of_uuids(self):
         u1, u2, u3, u4 = [uuid.uuid4() for _ in range(4)]
         a = UUIDList.create(key='a', id_list=[u1, u2, u3],
@@ -550,22 +544,11 @@ class TestTSVectorField(ModelTestCase):
         self.assertMessages(M('faith things', plain=True), [2, 4])
 
 
-def pg93():
-    with db:
-        return db.connection().server_version >= 90300
-
-def pg10():
-    with db:
-        return db.connection().server_version >= 100000
-
 def pg12():
     with db:
-        return db.connection().server_version >= 120000
-
-JSON_SUPPORT = (JsonModel is not None) and pg93()
+        return db.server_version >= 120000
 
 
-@skip_unless(JSON_SUPPORT, 'json support unavailable')
 class TestJsonField(BaseJsonFieldTestCase, ModelTestCase):
     M = JsonModel
     N = Normal
@@ -586,14 +569,12 @@ class TestJsonField(BaseJsonFieldTestCase, ModelTestCase):
         self.assertEqual(query.get(), tjn)
 
 
-@skip_unless(JSON_SUPPORT, 'json support unavailable')
 class TestBinaryJsonField(BaseBinaryJsonFieldTestCase, ModelTestCase):
     M = BJson
     N = Normal
     database = db
     requires = [BJson, Normal]
 
-    @skip_unless(pg10(), 'jsonb remove support requires pg >= 10')
     def test_remove_data(self):
         BJson.delete().execute()  # Clear out db.
         BJson.create(data={
@@ -613,7 +594,6 @@ class TestBinaryJsonField(BaseBinaryJsonFieldTestCase, ModelTestCase):
         assertData(['k1', 'kx', 'ky', 'k3'], {'k2': 'v2', 'k4': [0, 1, 2]})
         assertData(['k4', 'k3'], {'k1': 'v1', 'k2': 'v2'})
 
-    @skip_unless(pg10(), 'jsonb remove support requires pg >= 10')
     def test_json_contains_in_list(self):
         m1 = self.M.create(data=[{'k1': 'v1', 'k2': 'v2'}, {'a1': 'b1'}])
         m2 = self.M.create(data=[{'k3': 'v3'}, {'k4': 'v4'}])
@@ -638,25 +618,6 @@ class TestBinaryJsonField(BaseBinaryJsonFieldTestCase, ModelTestCase):
         self.assertRaises(ProgrammingError, fails)
 
 
-@skip_unless(JSON_SUPPORT, 'json support unavailable')
-class TestBinaryJsonFieldBulkUpdate(ModelTestCase):
-    database = db
-    requires = [BJson]
-
-    def test_binary_json_field_bulk_update(self):
-        b1 = BJson.create(data={'k1': 'v1'})
-        b2 = BJson.create(data={'k2': 'v2'})
-        b1.data['k1'] = 'v1-x'
-        b2.data['k2'] = 'v2-y'
-        BJson.bulk_update([b1, b2], fields=[BJson.data])
-
-        b1_db = BJson.get(BJson.id == b1.id)
-        b2_db = BJson.get(BJson.id == b2.id)
-        self.assertEqual(b1_db.data, {'k1': 'v1-x'})
-        self.assertEqual(b2_db.data, {'k2': 'v2-y'})
-
-
-@skip_unless(JSON_SUPPORT, 'json support unavailable')
 class TestJsonFieldRegressions(ModelTestCase):
     database = db
     requires = [JData]
@@ -750,7 +711,6 @@ class IDByDefault(TestModel):
     data = CharField()
 
 
-@skip_unless(pg10(), 'identity field requires pg >= 10')
 class TestIdentityField(ModelTestCase):
     database = db
     requires = [IDAlways, IDByDefault]
@@ -805,25 +765,42 @@ class TestServerSide(ModelTestCase):
 
     def test_server_side_cursor(self):
         query = Register.select().order_by(Register.value)
-        with self.assertQueryCount(1):
-            data = [row.value for row in ServerSide(query)]
-            self.assertEqual(data, list(range(100)))
+        with self.database.atomic():
+            with self.assertQueryCount(1):
+                data = [row.value for row in ServerSide(query)]
+                self.assertEqual(data, list(range(100)))
 
-        ss_query = ServerSide(query.limit(10), array_size=3)
-        self.assertEqual([row.value for row in ss_query], list(range(10)))
+            ss_query = ServerSide(query.limit(10), array_size=3)
+            self.assertEqual([row.value for row in ss_query], list(range(10)))
 
-        ss_query = ServerSide(query.where(SQL('1 = 0')))
-        self.assertEqual(list(ss_query), [])
+            ss_query = ServerSide(query.where(SQL('1 = 0')))
+            self.assertEqual(list(ss_query), [])
 
     def test_lower_level_apis(self):
         query = Register.select(Register.value).order_by(Register.value)
-        ssq = ServerSideQuery(query, array_size=10)
-        curs_wrapper = ssq._execute(self.database)
-        curs = curs_wrapper.cursor
-        self.assertTrue(isinstance(curs, FetchManyCursor))
-        self.assertEqual(curs.fetchone(), (0,))
-        self.assertEqual(curs.fetchone(), (1,))
-        curs.close()
+        with self.database.atomic():
+            ssq = ServerSideQuery(query, array_size=10)
+            curs_wrapper = ssq._execute(self.database)
+            curs = curs_wrapper.cursor
+            self.assertTrue(isinstance(curs, FetchManyCursor))
+            self.assertEqual(curs.fetchone(), (0,))
+            self.assertEqual(curs.fetchone(), (1,))
+            curs.close()
+
+    def test_close_cursor(self):
+        query = Register.select(Register.value).order_by(Register.value)
+        with self.database.atomic():
+            ssq = ServerSideQuery(query, array_size=10)
+            accum = []
+            for i, obj in enumerate(ssq.iterator()):
+                if i == 25:
+                    break
+                accum.append(obj.value)
+
+            self.assertTrue(ssq.close())
+
+        self.assertEqual(len(accum), 25)
+        self.assertEqual(accum, list(range(25)))
 
 
 class KX(TestModel):
@@ -918,7 +895,6 @@ class TestPostgresCTEMaterialization(ModelTestCase):
             self.assertEqual([r.value for r in query], [1, 3])
 
 
-@skip_unless(pg93(), 'lateral join requires pg >= 9.3')
 class TestPostgresLateralJoin(ModelTestCase):
     database = db
     test_data = (
